@@ -29,7 +29,7 @@
 
 newtargets=function(object,newdata,k=NULL,ann=NULL)
 {
-   if (class(object) != "yai") stop ("object must be class yai")
+   if(!inherits(object, "yai")) stop ("object must be class yai")
    if (object$method == "ensemble") 
      stop ("newtargets can not be found for objects with method 'ensemble'.")
    if (is.null(newdata) | nrow(newdata)==0) stop ("newdata is required")
@@ -78,7 +78,8 @@ newtargets=function(object,newdata,k=NULL,ann=NULL)
           missing = setdiff(colnames(object$xRefs),colnames(newdata))     
           stop(paste("required column(s) missing:", paste (missing, collapse=", ")))
       }
-      xall=na.omit(newdata[,have])
+      xall=na.omit(as.data.frame(newdata[,have]))
+      colnames(xall) = have
       obsDropped=names(attributes(na.omit(xall))$na.action)
       if (length(obsDropped)>0) warning (nrow(newdata)-nrow(xall)," observation(s) removed")
    }
