@@ -3,7 +3,7 @@
 
 yaiVarImp = function(object, nTop=20, plot=TRUE, ...)
 {
-   if (class(object) != "yai") stop ("arg must be of class yai")
+   if(!inherits(object, "yai")) stop ("arg must be of class yai")
    if (object$method != "randomForest") stop ("method must be randomForest")
    if (!requireNamespace ("randomForest")) 
    {
